@@ -120,7 +120,7 @@ int hns_roce_u_free_pd(struct ibv_pd *pd)
 }
 
 struct ibv_mr *hns_roce_u_reg_mr(struct ibv_pd *pd, void *addr, size_t length,
-				 int access)
+				 uint64_t hca_va, int access)
 {
 	int ret;
 	struct verbs_mr *vmr;
@@ -141,8 +141,8 @@ struct ibv_mr *hns_roce_u_reg_mr(struct ibv_pd *pd, void *addr, size_t length,
 	if (!vmr)
 		return NULL;
 
-	ret = ibv_cmd_reg_mr(pd, addr, length, (uintptr_t)addr, access, vmr,
-			     &cmd, sizeof(cmd), &resp, sizeof(resp));
+	ret = ibv_cmd_reg_mr(pd, addr, length, hca_va, access, vmr, &cmd,
+			     sizeof(cmd), &resp, sizeof(resp));
 	if (ret) {
 		free(vmr);
 		return NULL;
@@ -183,15 +183,15 @@ int hns_roce_u_bind_mw(struct ibv_qp *qp, struct ibv_mw *mw,
 	struct ibv_send_wr wr = {};
 	int ret;
 
+	if (!bind_info->mr && bind_info->length)
+		return EINVAL;
+
 	if ((mw->pd != qp->pd) || (mw->pd != bind_info->mr->pd))
 		return EINVAL;
 
 	if (mw->type != IBV_MW_TYPE_1)
 		return EINVAL;
 
-	if (!bind_info->mr && bind_info->length)
-		return EINVAL;
-
 	if (bind_info->mw_access_flags & ~(IBV_ACCESS_REMOTE_WRITE |
 	    IBV_ACCESS_REMOTE_READ | IBV_ACCESS_REMOTE_ATOMIC))
 		return EINVAL;
@@ -644,9 +644,6 @@ static int hns_roce_verify_qp(struct ibv_qp_init_attr *attr,
 	    (attr->cap.max_inline_data > HNS_ROCE_MAX_INLINE_DATA_LEN))
 		return -1;
 
-	if (attr->qp_type == IBV_QPT_UC)
-		return -1;
-
 	return 0;
 }
 
@@ -774,7 +771,7 @@ static int hns_roce_alloc_qp_buf(struct ibv_pd *pd, struct ibv_qp_cap *cap,
 		return -1;
 	}
 
-	memset(qp->buf.buf, 0, qp->buf_size);
+	memset(qp->buf.buf, 0, qp->buf.length);
 
 	return 0;
 }
