@@ -630,6 +630,11 @@ struct mlx5_mkey {
 	uint16_t num_desc;
 };
 
+struct mlx5_devx_event_channel {
+	struct ibv_context *context;
+	struct mlx5dv_devx_event_channel dv_event_channel;
+};
+
 static inline int mlx5_ilog2(int n)
 {
 	int t;
@@ -816,8 +821,8 @@ void mlx5_async_event(struct ibv_context *context,
 		      struct ibv_async_event *event);
 
 struct ibv_mr *mlx5_alloc_null_mr(struct ibv_pd *pd);
-struct ibv_mr *mlx5_reg_mr(struct ibv_pd *pd, void *addr,
-			   size_t length, int access);
+struct ibv_mr *mlx5_reg_mr(struct ibv_pd *pd, void *addr, size_t length,
+			   uint64_t hca_va, int access);
 int mlx5_rereg_mr(struct verbs_mr *mr, int flags, struct ibv_pd *pd, void *addr,
 		  size_t length, int access);
 int mlx5_dereg_mr(struct verbs_mr *mr);
