@@ -1569,14 +1569,14 @@ enum {
 	MLX5_ACTION_IN_FIELD_OUT_SIPV4         = 0x15,
 	MLX5_ACTION_IN_FIELD_OUT_DIPV4         = 0x16,
 	MLX5_ACTION_IN_FIELD_OUT_IPV6_HOPLIMIT = 0x47,
-	MLX5_ACTION_IN_FIELD_OUT_MEGADATA_REGA = 0x49,
-	MLX5_ACTION_IN_FIELD_OUT_MEGADATA_REGB = 0x50,
-	MLX5_ACTION_IN_FIELD_OUT_MEGADATA_REGC_0 = 0x51,
-	MLX5_ACTION_IN_FIELD_OUT_MEGADATA_REGC_1 = 0x52,
-	MLX5_ACTION_IN_FIELD_OUT_MEGADATA_REGC_2 = 0x53,
-	MLX5_ACTION_IN_FIELD_OUT_MEGADATA_REGC_3 = 0x54,
-	MLX5_ACTION_IN_FIELD_OUT_MEGADATA_REGC_4 = 0x55,
-	MLX5_ACTION_IN_FIELD_OUT_MEGADATA_REGC_5 = 0x56,
+	MLX5_ACTION_IN_FIELD_OUT_METADATA_REGA = 0x49,
+	MLX5_ACTION_IN_FIELD_OUT_METADATA_REGB = 0x50,
+	MLX5_ACTION_IN_FIELD_OUT_METADATA_REGC_0 = 0x51,
+	MLX5_ACTION_IN_FIELD_OUT_METADATA_REGC_1 = 0x52,
+	MLX5_ACTION_IN_FIELD_OUT_METADATA_REGC_2 = 0x53,
+	MLX5_ACTION_IN_FIELD_OUT_METADATA_REGC_3 = 0x54,
+	MLX5_ACTION_IN_FIELD_OUT_METADATA_REGC_4 = 0x55,
+	MLX5_ACTION_IN_FIELD_OUT_METADATA_REGC_5 = 0x56,
 	MLX5_ACTION_IN_FIELD_OUT_TCP_SEQ_NUM   = 0x59,
 	MLX5_ACTION_IN_FIELD_OUT_TCP_ACK_NUM   = 0x5B,
 };
